declare module "prism-editor" {
    /** Disclaimer: inspired by https://github.com/koca/vue-prism-editor/ */
    import type { IHydratedController } from '@aurelia/runtime-html';
    import { type ICustomElementViewModel } from 'aurelia';
    import 'prismjs/components/prism-cmake.js';
    import 'prismjs/components/prism-javascript.js';
    import 'prismjs/components/prism-json.js';
    import 'prismjs/plugins/line-numbers/prism-line-numbers.js';
    export interface EditorProps {
        lineNumbers: boolean;
        autoStyleLineNumbers: boolean;
        readonly: boolean;
        value: string;
        highlight: () => string;
        tabSize: number;
        insertSpaces: boolean;
        ignoreTabKey: boolean;
        placeholder: string;
    }
    export interface Record {
        value: string;
        selectionStart: number;
        selectionEnd: number;
    }
    export interface History {
        stack: Array<Record & {
            timestamp: number;
        }>;
        offset: number;
    }
    /**
     * Prism Editor
     */
    export class PrismEditor implements ICustomElementViewModel {
        private readonly _element;
        private static readonly _KEY_ENTER;
        private static readonly _KEY_TAB;
        private static readonly _KEY_BACKSPACE;
        private static readonly _KEY_Y;
        private static readonly _KEY_Z;
        private static readonly _KEY_M;
        private static readonly _KEY_PARENS;
        private static readonly _KEY_BRACKETS;
        private static readonly _KEY_QUOTE;
        private static readonly _KEY_BACK_QUOTE;
        private static readonly _KEY_ESCAPE;
        private static readonly _HISTORY_LIMIT;
        private static readonly _HISTORY_TIME_GAP;
        preRef: HTMLPreElement;
        textAreaRef: HTMLTextAreaElement;
        private _boundedKeydown;
        constructor(_element: HTMLElement);
        lineNumbers: boolean;
        lineNumbersChanged(): void;
        autoStyleLineNumbers: boolean;
        readonly: boolean;
        code: string;
        highlight: Function;
        tabSize: number;
        insertSpaces: boolean;
        ignoreTabKey: boolean;
        placeholder: string;
        contentChanged(): void;
        get isEmpty(): boolean;
        generateContent(): string;
        get lineNumbersCount(): number;
        capture: boolean;
        history: History;
        lineNumbersHeight: string;
        bound(initiator: IHydratedController, parent: IHydratedController): void | Promise<void>;
        attached(initiator: IHydratedController): void | Promise<void>;
        detaching(initiator: IHydratedController, parent: IHydratedController): void | Promise<void>;
        setLineNumbersHeight(): void;
        styleLineNumbers(): void;
        private _getLines;
        private _applyEdits;
        private _recordChange;
        private _updateInput;
        codeChanged(newValue: string, oldValue: string): void;
        /** Undo */
        undo(): void;
        /** Redo */
        private redo;
        handleKeyDown(e: KeyboardEvent): boolean;
        $emit(evName: string, params: any): void;
    }
}
declare module "prism-view" {
    import { IHydratedController } from '@aurelia/runtime-html';
    import { type ICustomElementViewModel } from 'aurelia';
    import 'prismjs/components/prism-cmake.js';
    import 'prismjs/components/prism-javascript.js';
    import 'prismjs/components/prism-json.js';
    import 'prismjs/plugins/line-numbers/prism-line-numbers.js';
    /**
     * CodeMirror
     */
    export class PrismView implements ICustomElementViewModel {
        private readonly _element;
        codeArea: HTMLElement;
        /** Code */
        code: string;
        language: string;
        lineNumbers: boolean;
        constructor(_element: HTMLElement);
        attached(initiator: IHydratedController): void | Promise<void>;
        codeChanged(newValue: string, oldValue: string): void;
    }
}
declare module "index" {
    export { PrismEditor } from "prism-editor";
    export { PrismView } from "prism-view";
}

declare module "@aegenet/au2-prism" {
    export * from "src/index";
}
